#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 what4
version:              1.6
visibility:           public
id:                   what4-1.6-ETUxii12vPaFhFuefIVz5f
key:                  what4-1.6-ETUxii12vPaFhFuefIVz5f
license:              BSD-3-Clause
copyright:            (c) Galois, Inc 2014-2023
maintainer:           rscott@galois.com, kquick@galois.com
author:               Galois Inc.
homepage:             https://github.com/GaloisInc/what4
synopsis:             Solver-agnostic symbolic values support for issuing queries
description:
    What4 is a generic library for representing values as symbolic formulae which may
    contain references to symbolic values, representing unknown variables.
    It provides support for communicating with a variety of SAT and SMT solvers,
    including Z3, CVC4, CVC5, Yices, Bitwuzla, Boolector, STP, and dReal.
    The data representation types make heavy use of GADT-style type indices
    to ensure type-correct manipulation of symbolic values.

category:             Formal Methods, Theorem Provers, Symbolic Computation, SMT
abi:                  d604947f499b4f9de3fd85b8267cc776
exposed:              True
exposed-modules:
    Test.Verification What4.BaseTypes What4.Concrete What4.Config
    What4.Expr What4.Expr.Allocator What4.Expr.App What4.Expr.AppTheory
    What4.Expr.ArrayUpdateMap What4.Expr.BoolMap What4.Expr.Builder
    What4.Expr.GroundEval What4.Expr.MATLAB What4.Expr.Simplify
    What4.Expr.StringSeq What4.Expr.UnaryBV
    What4.Expr.VarIdentification What4.Expr.WeightedSum What4.FloatMode
    What4.FunctionName What4.IndexLit What4.Interface
    What4.InterpretedFloatingPoint What4.LabeledPred What4.Panic
    What4.Partial What4.ProblemFeatures What4.ProgramLoc
    What4.Protocol.Online What4.Protocol.PolyRoot
    What4.Protocol.ReadDecimal What4.Protocol.SExp
    What4.Protocol.SMTLib2 What4.Protocol.SMTLib2.Parse
    What4.Protocol.SMTLib2.Response What4.Protocol.SMTLib2.Syntax
    What4.Protocol.SMTWriter What4.Protocol.VerilogWriter
    What4.Protocol.VerilogWriter.ABCVerilog
    What4.Protocol.VerilogWriter.AST
    What4.Protocol.VerilogWriter.Backend What4.SFloat What4.SWord
    What4.SatResult What4.SemiRing What4.Serialize.FastSExpr
    What4.Serialize.Log What4.Serialize.Normalize
    What4.Serialize.Parser What4.Serialize.Printer
    What4.Serialize.SETokens What4.Solver What4.Solver.Adapter
    What4.Solver.Bitwuzla What4.Solver.Boolector What4.Solver.CVC4
    What4.Solver.CVC5 What4.Solver.DReal What4.Solver.ExternalABC
    What4.Solver.STP What4.Solver.Yices What4.Solver.Z3
    What4.SpecialFunctions What4.Symbol What4.Utils.AbstractDomains
    What4.Utils.AnnotatedMap What4.Utils.Arithmetic
    What4.Utils.BVDomain What4.Utils.BVDomain.Arith
    What4.Utils.BVDomain.Bitwise What4.Utils.BVDomain.XOR
    What4.Utils.Complex What4.Utils.Endian What4.Utils.Environment
    What4.Utils.FloatHelpers What4.Utils.HandleReader
    What4.Utils.IncrHash What4.Utils.LeqMap What4.Utils.MonadST
    What4.Utils.OnlyIntRepr What4.Utils.Process
    What4.Utils.ResolveBounds.BV What4.Utils.Serialize
    What4.Utils.Streams What4.Utils.StringLiteral What4.Utils.Versions
    What4.Utils.Word16String What4.WordMap

import-dirs:          /usr/lib/ghc-9.6.6/site-local/what4-1.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/what4-1.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/what4-1.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-what4
hs-libraries:         HSwhat4-1.6-ETUxii12vPaFhFuefIVz5f
depends:
    BoundedChan-1.0.3.0-KC4GwTTdtFBGyIaMAN8c52
    async-2.2.6-EpK7QlrOASTBz80Gb3A8ju
    attoparsec-0.14.4-8Ihrc92tki9CPtxJ7iMWhq base-4.18.2.1
    bifunctors-5.6.3-IK0L300ZiFLHyh3NXtVsdP
    bimap-0.5.0-hDs4uvr4oTJFK8ty8FwwG
    bv-sized-1.0.6-DXnXflOXmSZDzHFwEVqrhl bytestring-0.11.5.3
    concurrent-extra-0.7.0.12-4RG8xnAPc0P6qZxwQC16Sg
    config-value-0.8.3-IWIlPmbx9u07ZPnTUBDeDU containers-0.6.7
    deepseq-1.4.8.1 deriving-compat-0.6.8-AeOZDdkjLVBwn3erCwEcQ
    directory-1.3.8.5 exceptions-0.10.7 filepath-1.4.300.1
    fingertree-0.1.6.3-BO1UjMokPfw2j0fPStsRsA ghc-prim-0.10.0
    hashable-1.4.7.0-CNoNcGLK9KJ5X5nXfJeai3
    hashtables-1.4.2-7OTDyo7VrIdABef0hj3WnV
    io-streams-1.5.2.2-8WX71GOGVSUBN8Y5BXyfTg
    lens-5.3.4-LJxgvHYoW262GPTLIzFlhY
    libBF-0.6.7-LT6YW09bwzMHDWKd4SSei9
    megaparsec-9.7.0-HwFCj8AZlAe6hd0TjBRiui mtl-2.3.1
    ordered-containers-0.2.4-BRmHofT5nEWKcylWp8tw8R
    panic-0.4.0.1-LjSerD2Hu1fK37HhFAQEbK
    parameterized-utils-2.1.11.0-D6O1iZttZR279xbId5ZAzB parsec-3.1.16.1
    prettyprinter-1.7.1-DrhJgh2zvVyDSlphpqlv9X process-1.6.19.0
    s-cargot-0.1.6.0-99p2G5eHHvb9qObNPPTKGK
    scientific-0.3.8.1-9lNiUg0NFGt8fB4Ap5FVsD stm-2.5.1.0
    template-haskell-2.20.0.0 temporary-1.3-C4AWJcx6OU755V1dgCzpdm
    text-2.0.2 th-lift-0.8.6-259dLbfPJk9HrfYIeZHdvQ
    th-lift-instances-0.1.20-Ix2EIDBaHlS3YmmEGgSZoJ time-1.12.2
    transformers-0.6.1.0 unliftio-0.2.25.1-KBv4DTXvafxB4kek08uChL
    unordered-containers-0.2.20.1-HfKtyefgs0b2egKrxLGXU0
    utf8-string-1.0.2-2At7L47Qsbs4rlGLlJEQb1
    vector-0.13.2.0-7eILYIgfGZSAohY3MIpZY
    versions-6.0.8-BxWNOTLED2RIM4ZyolR0eG
    zenc-0.1.2-BbMrrIyy5KQ8k9eqETMNr9

haddock-interfaces:   /usr/share/doc/haskell-what4/html/what4.haddock
haddock-html:         /usr/share/doc/haskell-what4/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

